@@ -76,12 +76,12 @@ extern int Barcode_isbn_verify(unsigned char *text);
 extern int Barcode_isbn_encode(struct Barcode_Item *bc);
 extern int Barcode_39_verify(unsigned char *text);
 extern int Barcode_39_encode(struct Barcode_Item *bc);
-#if 0 /* not yet implemented */
-extern int Barcode_128_verify(unsigned char *text);
-extern int Barcode_128_encode(struct Barcode_Item *bc);
+extern int Barcode_128b_verify(unsigned char *text);
+extern int Barcode_128b_encode(struct Barcode_Item *bc);
 extern int Barcode_128c_verify(unsigned char *text);
 extern int Barcode_128c_encode(struct Barcode_Item *bc);
-#endif
+extern int Barcode_i25_verify(unsigned char *text);
+extern int Barcode_i25_encode(struct Barcode_Item *bc);
 
 struct encoding {
     int type;
@@ -93,11 +93,10 @@ struct encoding encodings[] = {
     {BARCODE_EAN,  Barcode_ean_verify,  Barcode_ean_encode},
     {BARCODE_UPC,  Barcode_upc_verify,  Barcode_upc_encode},
     {BARCODE_ISBN, Barcode_isbn_verify, Barcode_isbn_encode},
+    {BARCODE_128B, Barcode_128b_verify, Barcode_128b_encode},
+    {BARCODE_128C, Barcode_128c_verify, Barcode_128c_encode},
     {BARCODE_39,   Barcode_39_verify,   Barcode_39_encode},
-#if 0 /* not yet implemented */
-    {BARCODE_128,  Barcode_128_verify,  Barcode_128_encode},
-    {BARCODE_128C, Barcode_128_verify,  Barcode_128_encode},
-#endif
+    {BARCODE_I25,  Barcode_i25_verify,  Barcode_i25_encode},
     {0,            NULL,                NULL}
 };
 
